syntax = "proto3";
package sentinel.provider.v1;

option go_package = "github.com/sentinel-official/hub/x/provider/types";

import "gogoproto/gogo.proto";

option (gogoproto.equal_all)           = false;
option (gogoproto.goproto_getters_all) = false;

message Provider {
  string address     = 1;
  string name        = 2;
  string identity    = 3;
  string website     = 4;
  string description = 5;
}
