# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sentinel/plan/v1/querier.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from sentinel.node.v1 import node_pb2 as sentinel_dot_node_dot_v1_dot_node__pb2
from sentinel.plan.v1 import plan_pb2 as sentinel_dot_plan_dot_v1_dot_plan__pb2
from sentinel.types.v1 import status_pb2 as sentinel_dot_types_dot_v1_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1esentinel/plan/v1/querier.proto\x12\x10sentinel.plan.v1\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1bsentinel/node/v1/node.proto\x1a\x1bsentinel/plan/v1/plan.proto\x1a\x1esentinel/types/v1/status.proto\"z\n\x11QueryPlansRequest\x12)\n\x06status\x18\x01 \x01(\x0e\x32\x19.sentinel.types.v1.Status\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x96\x01\n\x1cQueryPlansForProviderRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12)\n\x06status\x18\x02 \x01(\x0e\x32\x19.sentinel.types.v1.Status\x12:\n\npagination\x18\x03 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x1e\n\x10QueryPlanRequest\x12\n\n\x02id\x18\x01 \x01(\x04\"b\n\x18QueryNodesForPlanRequest\x12\n\n\x02id\x18\x01 \x01(\x04\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"~\n\x12QueryPlansResponse\x12+\n\x05plans\x18\x01 \x03(\x0b\x32\x16.sentinel.plan.v1.PlanB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"\x89\x01\n\x1dQueryPlansForProviderResponse\x12+\n\x05plans\x18\x01 \x03(\x0b\x32\x16.sentinel.plan.v1.PlanB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"?\n\x11QueryPlanResponse\x12*\n\x04plan\x18\x01 \x01(\x0b\x32\x16.sentinel.plan.v1.PlanB\x04\xc8\xde\x1f\x00\"\x85\x01\n\x19QueryNodesForPlanResponse\x12+\n\x05nodes\x18\x01 \x03(\x0b\x32\x16.sentinel.node.v1.NodeB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse2\xaf\x04\n\x0cQueryService\x12p\n\nQueryPlans\x12#.sentinel.plan.v1.QueryPlansRequest\x1a$.sentinel.plan.v1.QueryPlansResponse\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/sentinel/plans\x12\xa5\x01\n\x15QueryPlansForProvider\x12..sentinel.plan.v1.QueryPlansForProviderRequest\x1a/.sentinel.plan.v1.QueryPlansForProviderResponse\"+\x82\xd3\xe4\x93\x02%\x12#/sentinel/providers/{address}/plans\x12r\n\tQueryPlan\x12\".sentinel.plan.v1.QueryPlanRequest\x1a#.sentinel.plan.v1.QueryPlanResponse\"\x1c\x82\xd3\xe4\x93\x02\x16\x12\x14/sentinel/plans/{id}\x12\x90\x01\n\x11QueryNodesForPlan\x12*.sentinel.plan.v1.QueryNodesForPlanRequest\x1a+.sentinel.plan.v1.QueryNodesForPlanResponse\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/sentinel/plans/{id}/nodesB7Z-github.com/sentinel-official/hub/x/plan/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.plan.v1.querier_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/sentinel-official/hub/x/plan/types\250\342\036\000\310\341\036\000'
  _QUERYPLANSRESPONSE.fields_by_name['plans']._options = None
  _QUERYPLANSRESPONSE.fields_by_name['plans']._serialized_options = b'\310\336\037\000'
  _QUERYPLANSFORPROVIDERRESPONSE.fields_by_name['plans']._options = None
  _QUERYPLANSFORPROVIDERRESPONSE.fields_by_name['plans']._serialized_options = b'\310\336\037\000'
  _QUERYPLANRESPONSE.fields_by_name['plan']._options = None
  _QUERYPLANRESPONSE.fields_by_name['plan']._serialized_options = b'\310\336\037\000'
  _QUERYNODESFORPLANRESPONSE.fields_by_name['nodes']._options = None
  _QUERYNODESFORPLANRESPONSE.fields_by_name['nodes']._serialized_options = b'\310\336\037\000'
  _QUERYSERVICE.methods_by_name['QueryPlans']._options = None
  _QUERYSERVICE.methods_by_name['QueryPlans']._serialized_options = b'\202\323\344\223\002\021\022\017/sentinel/plans'
  _QUERYSERVICE.methods_by_name['QueryPlansForProvider']._options = None
  _QUERYSERVICE.methods_by_name['QueryPlansForProvider']._serialized_options = b'\202\323\344\223\002%\022#/sentinel/providers/{address}/plans'
  _QUERYSERVICE.methods_by_name['QueryPlan']._options = None
  _QUERYSERVICE.methods_by_name['QueryPlan']._serialized_options = b'\202\323\344\223\002\026\022\024/sentinel/plans/{id}'
  _QUERYSERVICE.methods_by_name['QueryNodesForPlan']._options = None
  _QUERYSERVICE.methods_by_name['QueryNodesForPlan']._serialized_options = b'\202\323\344\223\002\034\022\032/sentinel/plans/{id}/nodes'
  _QUERYPLANSREQUEST._serialized_start=238
  _QUERYPLANSREQUEST._serialized_end=360
  _QUERYPLANSFORPROVIDERREQUEST._serialized_start=363
  _QUERYPLANSFORPROVIDERREQUEST._serialized_end=513
  _QUERYPLANREQUEST._serialized_start=515
  _QUERYPLANREQUEST._serialized_end=545
  _QUERYNODESFORPLANREQUEST._serialized_start=547
  _QUERYNODESFORPLANREQUEST._serialized_end=645
  _QUERYPLANSRESPONSE._serialized_start=647
  _QUERYPLANSRESPONSE._serialized_end=773
  _QUERYPLANSFORPROVIDERRESPONSE._serialized_start=776
  _QUERYPLANSFORPROVIDERRESPONSE._serialized_end=913
  _QUERYPLANRESPONSE._serialized_start=915
  _QUERYPLANRESPONSE._serialized_end=978
  _QUERYNODESFORPLANRESPONSE._serialized_start=981
  _QUERYNODESFORPLANRESPONSE._serialized_end=1114
  _QUERYSERVICE._serialized_start=1117
  _QUERYSERVICE._serialized_end=1676
# @@protoc_insertion_point(module_scope)
