syntax = "proto3";
package sentinel.node.v1;

option go_package = "github.com/sentinel-official/hub/x/node/types";

import "gogoproto/gogo.proto";
import "cosmos/base/v1beta1/coin.proto";
import "sentinel/types/v1/status.proto";

option (gogoproto.equal_all)           = false;
option (gogoproto.goproto_getters_all) = false;

// MsgRegisterRequest defines the SDK message for registering a node
message MsgRegisterRequest {
  string frm                             = 1;
  string provider                         = 2;
  repeated cosmos.base.v1beta1.Coin price = 3 [
    (gogoproto.nullable)     = false,
    (gogoproto.castrepeated) = "github.com/cosmos/cosmos-sdk/types.Coins"
  ];
  string remote_url = 4 [ (gogoproto.customname) = "RemoteURL" ];
}

// MsgUpdateRequest defines the SDK message for updating a node
message MsgUpdateRequest {
  string frm                             = 1;
  string provider                         = 2;
  repeated cosmos.base.v1beta1.Coin price = 3 [
    (gogoproto.nullable)     = false,
    (gogoproto.castrepeated) = "github.com/cosmos/cosmos-sdk/types.Coins"
  ];
  string remote_url = 4 [ (gogoproto.customname) = "RemoteURL" ];
}

// MsgSetStatusRequest defines the SDK message for modifying the status of a
// node
message MsgSetStatusRequest {
  string frm                     = 1;
  sentinel.types.v1.Status status = 2;
}

// MsgRegisterResponse defines the response of message MsgRegisterRequest
message MsgRegisterResponse {}

// MsgUpdateResponse defines the response of message MsgUpdateRequest
message MsgUpdateResponse {}

// MsgSetStatusResponse defines the response of message MsgSetStatusRequest
message MsgSetStatusResponse {}

service MsgService {
  rpc MsgRegister(MsgRegisterRequest) returns (MsgRegisterResponse);
  rpc MsgUpdate(MsgUpdateRequest) returns (MsgUpdateResponse);
  rpc MsgSetStatus(MsgSetStatusRequest) returns (MsgSetStatusResponse);
}
