# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sentinel/session/v1/proof.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from sentinel.types.v1 import bandwidth_pb2 as sentinel_dot_types_dot_v1_dot_bandwidth__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fsentinel/session/v1/proof.proto\x12\x13sentinel.session.v1\x1a\x14gogoproto/gogo.proto\x1a\x1egoogle/protobuf/duration.proto\x1a!sentinel/types/v1/bandwidth.proto\"\x81\x01\n\x05Proof\x12\n\n\x02id\x18\x01 \x01(\x04\x12\x35\n\x08\x64uration\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\x98\xdf\x1f\x01\xc8\xde\x1f\x00\x12\x35\n\tbandwidth\x18\x03 \x01(\x0b\x32\x1c.sentinel.types.v1.BandwidthB\x04\xc8\xde\x1f\x00\x42:Z0github.com/sentinel-official/hub/x/session/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.session.v1.proof_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z0github.com/sentinel-official/hub/x/session/types\250\342\036\000\310\341\036\000'
  _PROOF.fields_by_name['duration']._options = None
  _PROOF.fields_by_name['duration']._serialized_options = b'\230\337\037\001\310\336\037\000'
  _PROOF.fields_by_name['bandwidth']._options = None
  _PROOF.fields_by_name['bandwidth']._serialized_options = b'\310\336\037\000'
  _PROOF._serialized_start=146
  _PROOF._serialized_end=275
# @@protoc_insertion_point(module_scope)
