# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sentinel/subscription/v1/querier.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from sentinel.subscription.v1 import quota_pb2 as sentinel_dot_subscription_dot_v1_dot_quota__pb2
from sentinel.types.v1 import status_pb2 as sentinel_dot_types_dot_v1_dot_status__pb2
from sentinel.subscription.v1 import subscription_pb2 as sentinel_dot_subscription_dot_v1_dot_subscription__pb2
from sentinel.subscription.v1 import params_pb2 as sentinel_dot_subscription_dot_v1_dot_params__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&sentinel/subscription/v1/querier.proto\x12\x18sentinel.subscription.v1\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a$sentinel/subscription/v1/quota.proto\x1a\x1esentinel/types/v1/status.proto\x1a+sentinel/subscription/v1/subscription.proto\x1a%sentinel/subscription/v1/params.proto\"W\n\x19QuerySubscriptionsRequest\x12:\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x9d\x01\n#QuerySubscriptionsForAddressRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12)\n\x06status\x18\x02 \x01(\x0e\x32\x19.sentinel.types.v1.Status\x12:\n\npagination\x18\x03 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"&\n\x18QuerySubscriptionRequest\x12\n\n\x02id\x18\x01 \x01(\x04\"0\n\x11QueryQuotaRequest\x12\n\n\x02id\x18\x01 \x01(\x04\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\t\"\\\n\x12QueryQuotasRequest\x12\n\n\x02id\x18\x01 \x01(\x04\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x14\n\x12QueryParamsRequest\"\x9e\x01\n\x1aQuerySubscriptionsResponse\x12\x43\n\rsubscriptions\x18\x01 \x03(\x0b\x32&.sentinel.subscription.v1.SubscriptionB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"\xa8\x01\n$QuerySubscriptionsForAddressResponse\x12\x43\n\rsubscriptions\x18\x01 \x03(\x0b\x32&.sentinel.subscription.v1.SubscriptionB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"_\n\x19QuerySubscriptionResponse\x12\x42\n\x0csubscription\x18\x01 \x01(\x0b\x32&.sentinel.subscription.v1.SubscriptionB\x04\xc8\xde\x1f\x00\"J\n\x12QueryQuotaResponse\x12\x34\n\x05quota\x18\x01 \x01(\x0b\x32\x1f.sentinel.subscription.v1.QuotaB\x04\xc8\xde\x1f\x00\"\x89\x01\n\x13QueryQuotasResponse\x12\x35\n\x06quotas\x18\x01 \x03(\x0b\x32\x1f.sentinel.subscription.v1.QuotaB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"M\n\x13QueryParamsResponse\x12\x36\n\x06params\x18\x01 \x01(\x0b\x32 .sentinel.subscription.v1.ParamsB\x04\xc8\xde\x1f\x00\x32\x81\x08\n\x0cQueryService\x12\xa0\x01\n\x12QuerySubscriptions\x12\x33.sentinel.subscription.v1.QuerySubscriptionsRequest\x1a\x34.sentinel.subscription.v1.QuerySubscriptionsResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/sentinel/subscriptions\x12\xd1\x01\n\x1cQuerySubscriptionsForAddress\x12=.sentinel.subscription.v1.QuerySubscriptionsForAddressRequest\x1a>.sentinel.subscription.v1.QuerySubscriptionsForAddressResponse\"2\x82\xd3\xe4\x93\x02,\x12*/sentinel/accounts/{address}/subscriptions\x12\xa2\x01\n\x11QuerySubscription\x12\x32.sentinel.subscription.v1.QuerySubscriptionRequest\x1a\x33.sentinel.subscription.v1.QuerySubscriptionResponse\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/sentinel/subscriptions/{id}\x12\x9e\x01\n\nQueryQuota\x12+.sentinel.subscription.v1.QueryQuotaRequest\x1a,.sentinel.subscription.v1.QueryQuotaResponse\"5\x82\xd3\xe4\x93\x02/\x12-/accounts/{address}/subscriptions/{id}/quotas\x12\x97\x01\n\x0bQueryQuotas\x12,.sentinel.subscription.v1.QueryQuotasRequest\x1a-.sentinel.subscription.v1.QueryQuotasResponse\"+\x82\xd3\xe4\x93\x02%\x12#/sentinel/subscriptions/{id}/quotas\x12\x99\x01\n\x0bQueryParams\x12,.sentinel.subscription.v1.QueryParamsRequest\x1a-.sentinel.subscription.v1.QueryParamsResponse\"-\x82\xd3\xe4\x93\x02\'\x12%/sentinel/modules/subscription/paramsB?Z5github.com/sentinel-official/hub/x/subscription/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.subscription.v1.querier_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z5github.com/sentinel-official/hub/x/subscription/types\250\342\036\000\310\341\036\000'
  _QUERYSUBSCRIPTIONSRESPONSE.fields_by_name['subscriptions']._options = None
  _QUERYSUBSCRIPTIONSRESPONSE.fields_by_name['subscriptions']._serialized_options = b'\310\336\037\000'
  _QUERYSUBSCRIPTIONSFORADDRESSRESPONSE.fields_by_name['subscriptions']._options = None
  _QUERYSUBSCRIPTIONSFORADDRESSRESPONSE.fields_by_name['subscriptions']._serialized_options = b'\310\336\037\000'
  _QUERYSUBSCRIPTIONRESPONSE.fields_by_name['subscription']._options = None
  _QUERYSUBSCRIPTIONRESPONSE.fields_by_name['subscription']._serialized_options = b'\310\336\037\000'
  _QUERYQUOTARESPONSE.fields_by_name['quota']._options = None
  _QUERYQUOTARESPONSE.fields_by_name['quota']._serialized_options = b'\310\336\037\000'
  _QUERYQUOTASRESPONSE.fields_by_name['quotas']._options = None
  _QUERYQUOTASRESPONSE.fields_by_name['quotas']._serialized_options = b'\310\336\037\000'
  _QUERYPARAMSRESPONSE.fields_by_name['params']._options = None
  _QUERYPARAMSRESPONSE.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _QUERYSERVICE.methods_by_name['QuerySubscriptions']._options = None
  _QUERYSERVICE.methods_by_name['QuerySubscriptions']._serialized_options = b'\202\323\344\223\002\031\022\027/sentinel/subscriptions'
  _QUERYSERVICE.methods_by_name['QuerySubscriptionsForAddress']._options = None
  _QUERYSERVICE.methods_by_name['QuerySubscriptionsForAddress']._serialized_options = b'\202\323\344\223\002,\022*/sentinel/accounts/{address}/subscriptions'
  _QUERYSERVICE.methods_by_name['QuerySubscription']._options = None
  _QUERYSERVICE.methods_by_name['QuerySubscription']._serialized_options = b'\202\323\344\223\002\036\022\034/sentinel/subscriptions/{id}'
  _QUERYSERVICE.methods_by_name['QueryQuota']._options = None
  _QUERYSERVICE.methods_by_name['QueryQuota']._serialized_options = b'\202\323\344\223\002/\022-/accounts/{address}/subscriptions/{id}/quotas'
  _QUERYSERVICE.methods_by_name['QueryQuotas']._options = None
  _QUERYSERVICE.methods_by_name['QueryQuotas']._serialized_options = b'\202\323\344\223\002%\022#/sentinel/subscriptions/{id}/quotas'
  _QUERYSERVICE.methods_by_name['QueryParams']._options = None
  _QUERYSERVICE.methods_by_name['QueryParams']._serialized_options = b'\202\323\344\223\002\'\022%/sentinel/modules/subscription/params'
  _QUERYSUBSCRIPTIONSREQUEST._serialized_start=318
  _QUERYSUBSCRIPTIONSREQUEST._serialized_end=405
  _QUERYSUBSCRIPTIONSFORADDRESSREQUEST._serialized_start=408
  _QUERYSUBSCRIPTIONSFORADDRESSREQUEST._serialized_end=565
  _QUERYSUBSCRIPTIONREQUEST._serialized_start=567
  _QUERYSUBSCRIPTIONREQUEST._serialized_end=605
  _QUERYQUOTAREQUEST._serialized_start=607
  _QUERYQUOTAREQUEST._serialized_end=655
  _QUERYQUOTASREQUEST._serialized_start=657
  _QUERYQUOTASREQUEST._serialized_end=749
  _QUERYPARAMSREQUEST._serialized_start=751
  _QUERYPARAMSREQUEST._serialized_end=771
  _QUERYSUBSCRIPTIONSRESPONSE._serialized_start=774
  _QUERYSUBSCRIPTIONSRESPONSE._serialized_end=932
  _QUERYSUBSCRIPTIONSFORADDRESSRESPONSE._serialized_start=935
  _QUERYSUBSCRIPTIONSFORADDRESSRESPONSE._serialized_end=1103
  _QUERYSUBSCRIPTIONRESPONSE._serialized_start=1105
  _QUERYSUBSCRIPTIONRESPONSE._serialized_end=1200
  _QUERYQUOTARESPONSE._serialized_start=1202
  _QUERYQUOTARESPONSE._serialized_end=1276
  _QUERYQUOTASRESPONSE._serialized_start=1279
  _QUERYQUOTASRESPONSE._serialized_end=1416
  _QUERYPARAMSRESPONSE._serialized_start=1418
  _QUERYPARAMSRESPONSE._serialized_end=1495
  _QUERYSERVICE._serialized_start=1498
  _QUERYSERVICE._serialized_end=2523
# @@protoc_insertion_point(module_scope)
