syntax = "proto3";
package interchain_security.ccv.v1;

import "google/api/annotations.proto";
import "cosmos/base/query/v1beta1/pagination.proto";
// this line is used by starport scaffolding # 1

option go_package = "github.com/cosmos/interchain-security/x/ccv/types";

// Query defines the gRPC querier service.
service Query {
  // this line is used by starport scaffolding # 2
}

// this line is used by starport scaffolding # 3
