# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sentinel/provider/v1/msg.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1esentinel/provider/v1/msg.proto\x12\x14sentinel.provider.v1\x1a\x14gogoproto/gogo.proto\"g\n\x12MsgRegisterRequest\x12\x0b\n\x03\x66rm\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08identity\x18\x03 \x01(\t\x12\x0f\n\x07website\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\"e\n\x10MsgUpdateRequest\x12\x0b\n\x03\x66rm\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08identity\x18\x03 \x01(\t\x12\x0f\n\x07website\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\"\x15\n\x13MsgRegisterResponse\"\x13\n\x11MsgUpdateResponse2\xce\x01\n\nMsgService\x12\x62\n\x0bMsgRegister\x12(.sentinel.provider.v1.MsgRegisterRequest\x1a).sentinel.provider.v1.MsgRegisterResponse\x12\\\n\tMsgUpdate\x12&.sentinel.provider.v1.MsgUpdateRequest\x1a\'.sentinel.provider.v1.MsgUpdateResponseB;Z1github.com/sentinel-official/hub/x/provider/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.provider.v1.msg_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1github.com/sentinel-official/hub/x/provider/types\250\342\036\000\310\341\036\000'
  _MSGREGISTERREQUEST._serialized_start=78
  _MSGREGISTERREQUEST._serialized_end=181
  _MSGUPDATEREQUEST._serialized_start=183
  _MSGUPDATEREQUEST._serialized_end=284
  _MSGREGISTERRESPONSE._serialized_start=286
  _MSGREGISTERRESPONSE._serialized_end=307
  _MSGUPDATERESPONSE._serialized_start=309
  _MSGUPDATERESPONSE._serialized_end=328
  _MSGSERVICE._serialized_start=331
  _MSGSERVICE._serialized_end=537
# @@protoc_insertion_point(module_scope)
