syntax = "proto3";
package sentinel.provider.v1;

option go_package = "github.com/sentinel-official/hub/x/provider/types";

import "gogoproto/gogo.proto";

option (gogoproto.equal_all)           = false;
option (gogoproto.goproto_getters_all) = false;

// MsgRegisterRequest defines the SDK message for registering a provider
message MsgRegisterRequest {
  string frm        = 1;
  string name        = 2;
  string identity    = 3;
  string website     = 4;
  string description = 5;
}

// MsgUpdateRequest defines the SDK message for updating a provider
message MsgUpdateRequest {
  string frm        = 1;
  string name        = 2;
  string identity    = 3;
  string website     = 4;
  string description = 5;
}

// MsgRegisterResponse defines the response of message MsgRegisterRequest
message MsgRegisterResponse {}

// MsgUpdateResponse defines the response of message MsgUpdateRequest
message MsgUpdateResponse {}

service MsgService {
  rpc MsgRegister(MsgRegisterRequest) returns (MsgRegisterResponse);
  rpc MsgUpdate(MsgUpdateRequest) returns (MsgUpdateResponse);
}
