# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sentinel/provider/v1/querier.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from sentinel.provider.v1 import provider_pb2 as sentinel_dot_provider_dot_v1_dot_provider__pb2
from sentinel.provider.v1 import params_pb2 as sentinel_dot_provider_dot_v1_dot_params__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"sentinel/provider/v1/querier.proto\x12\x14sentinel.provider.v1\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a#sentinel/provider/v1/provider.proto\x1a!sentinel/provider/v1/params.proto\"S\n\x15QueryProvidersRequest\x12:\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\'\n\x14QueryProviderRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\"\x14\n\x12QueryParamsRequest\"\x8e\x01\n\x16QueryProvidersResponse\x12\x37\n\tproviders\x18\x01 \x03(\x0b\x32\x1e.sentinel.provider.v1.ProviderB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"O\n\x15QueryProviderResponse\x12\x36\n\x08provider\x18\x01 \x01(\x0b\x32\x1e.sentinel.provider.v1.ProviderB\x04\xc8\xde\x1f\x00\"I\n\x13QueryParamsResponse\x12\x32\n\x06params\x18\x01 \x01(\x0b\x32\x1c.sentinel.provider.v1.ParamsB\x04\xc8\xde\x1f\x00\x32\xbb\x03\n\x0cQueryService\x12\x88\x01\n\x0eQueryProviders\x12+.sentinel.provider.v1.QueryProvidersRequest\x1a,.sentinel.provider.v1.QueryProvidersResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/sentinel/providers\x12\x8f\x01\n\rQueryProvider\x12*.sentinel.provider.v1.QueryProviderRequest\x1a+.sentinel.provider.v1.QueryProviderResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/sentinel/providers/{address}\x12\x8d\x01\n\x0bQueryParams\x12(.sentinel.provider.v1.QueryParamsRequest\x1a).sentinel.provider.v1.QueryParamsResponse\")\x82\xd3\xe4\x93\x02#\x12!/sentinel/modules/provider/paramsB;Z1github.com/sentinel-official/hub/x/provider/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.provider.v1.querier_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1github.com/sentinel-official/hub/x/provider/types\250\342\036\000\310\341\036\000'
  _QUERYPROVIDERSRESPONSE.fields_by_name['providers']._options = None
  _QUERYPROVIDERSRESPONSE.fields_by_name['providers']._serialized_options = b'\310\336\037\000'
  _QUERYPROVIDERRESPONSE.fields_by_name['provider']._options = None
  _QUERYPROVIDERRESPONSE.fields_by_name['provider']._serialized_options = b'\310\336\037\000'
  _QUERYPARAMSRESPONSE.fields_by_name['params']._options = None
  _QUERYPARAMSRESPONSE.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _QUERYSERVICE.methods_by_name['QueryProviders']._options = None
  _QUERYSERVICE.methods_by_name['QueryProviders']._serialized_options = b'\202\323\344\223\002\025\022\023/sentinel/providers'
  _QUERYSERVICE.methods_by_name['QueryProvider']._options = None
  _QUERYSERVICE.methods_by_name['QueryProvider']._serialized_options = b'\202\323\344\223\002\037\022\035/sentinel/providers/{address}'
  _QUERYSERVICE.methods_by_name['QueryParams']._options = None
  _QUERYSERVICE.methods_by_name['QueryParams']._serialized_options = b'\202\323\344\223\002#\022!/sentinel/modules/provider/params'
  _QUERYPROVIDERSREQUEST._serialized_start=228
  _QUERYPROVIDERSREQUEST._serialized_end=311
  _QUERYPROVIDERREQUEST._serialized_start=313
  _QUERYPROVIDERREQUEST._serialized_end=352
  _QUERYPARAMSREQUEST._serialized_start=354
  _QUERYPARAMSREQUEST._serialized_end=374
  _QUERYPROVIDERSRESPONSE._serialized_start=377
  _QUERYPROVIDERSRESPONSE._serialized_end=519
  _QUERYPROVIDERRESPONSE._serialized_start=521
  _QUERYPROVIDERRESPONSE._serialized_end=600
  _QUERYPARAMSRESPONSE._serialized_start=602
  _QUERYPARAMSRESPONSE._serialized_end=675
  _QUERYSERVICE._serialized_start=678
  _QUERYSERVICE._serialized_end=1121
# @@protoc_insertion_point(module_scope)
