# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sentinel/session/v1/querier.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from sentinel.types.v1 import status_pb2 as sentinel_dot_types_dot_v1_dot_status__pb2
from sentinel.session.v1 import session_pb2 as sentinel_dot_session_dot_v1_dot_session__pb2
from sentinel.session.v1 import params_pb2 as sentinel_dot_session_dot_v1_dot_params__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!sentinel/session/v1/querier.proto\x12\x13sentinel.session.v1\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1esentinel/types/v1/status.proto\x1a!sentinel/session/v1/session.proto\x1a sentinel/session/v1/params.proto\"R\n\x14QuerySessionsRequest\x12:\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x98\x01\n\x1eQuerySessionsForAddressRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12)\n\x06status\x18\x02 \x01(\x0e\x32\x19.sentinel.types.v1.Status\x12:\n\npagination\x18\x03 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"!\n\x13QuerySessionRequest\x12\n\n\x02id\x18\x01 \x01(\x04\"\x14\n\x12QueryParamsRequest\"\x8a\x01\n\x15QuerySessionsResponse\x12\x34\n\x08sessions\x18\x01 \x03(\x0b\x32\x1c.sentinel.session.v1.SessionB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"\x94\x01\n\x1fQuerySessionsForAddressResponse\x12\x34\n\x08sessions\x18\x01 \x03(\x0b\x32\x1c.sentinel.session.v1.SessionB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"K\n\x14QuerySessionResponse\x12\x33\n\x07session\x18\x01 \x01(\x0b\x32\x1c.sentinel.session.v1.SessionB\x04\xc8\xde\x1f\x00\"H\n\x13QueryParamsResponse\x12\x31\n\x06params\x18\x01 \x01(\x0b\x32\x1b.sentinel.session.v1.ParamsB\x04\xc8\xde\x1f\x00\x32\xdd\x04\n\x0cQueryService\x12\x82\x01\n\rQuerySessions\x12).sentinel.session.v1.QuerySessionsRequest\x1a*.sentinel.session.v1.QuerySessionsResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\x12\x12/sentinel/sessions\x12\xb3\x01\n\x17QuerySessionsForAddress\x12\x33.sentinel.session.v1.QuerySessionsForAddressRequest\x1a\x34.sentinel.session.v1.QuerySessionsForAddressResponse\"-\x82\xd3\xe4\x93\x02\'\x12%/sentinel/accounts/{address}/sessions\x12\x84\x01\n\x0cQuerySession\x12(.sentinel.session.v1.QuerySessionRequest\x1a).sentinel.session.v1.QuerySessionResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/sentinel/sessions/{id}\x12\x8a\x01\n\x0bQueryParams\x12\'.sentinel.session.v1.QueryParamsRequest\x1a(.sentinel.session.v1.QueryParamsResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /sentinel/modules/session/paramsB:Z0github.com/sentinel-official/hub/x/session/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.session.v1.querier_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z0github.com/sentinel-official/hub/x/session/types\250\342\036\000\310\341\036\000'
  _QUERYSESSIONSRESPONSE.fields_by_name['sessions']._options = None
  _QUERYSESSIONSRESPONSE.fields_by_name['sessions']._serialized_options = b'\310\336\037\000'
  _QUERYSESSIONSFORADDRESSRESPONSE.fields_by_name['sessions']._options = None
  _QUERYSESSIONSFORADDRESSRESPONSE.fields_by_name['sessions']._serialized_options = b'\310\336\037\000'
  _QUERYSESSIONRESPONSE.fields_by_name['session']._options = None
  _QUERYSESSIONRESPONSE.fields_by_name['session']._serialized_options = b'\310\336\037\000'
  _QUERYPARAMSRESPONSE.fields_by_name['params']._options = None
  _QUERYPARAMSRESPONSE.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _QUERYSERVICE.methods_by_name['QuerySessions']._options = None
  _QUERYSERVICE.methods_by_name['QuerySessions']._serialized_options = b'\202\323\344\223\002\024\022\022/sentinel/sessions'
  _QUERYSERVICE.methods_by_name['QuerySessionsForAddress']._options = None
  _QUERYSERVICE.methods_by_name['QuerySessionsForAddress']._serialized_options = b'\202\323\344\223\002\'\022%/sentinel/accounts/{address}/sessions'
  _QUERYSERVICE.methods_by_name['QuerySession']._options = None
  _QUERYSERVICE.methods_by_name['QuerySession']._serialized_options = b'\202\323\344\223\002\031\022\027/sentinel/sessions/{id}'
  _QUERYSERVICE.methods_by_name['QueryParams']._options = None
  _QUERYSERVICE.methods_by_name['QueryParams']._serialized_options = b'\202\323\344\223\002\"\022 /sentinel/modules/session/params'
  _QUERYSESSIONSREQUEST._serialized_start=255
  _QUERYSESSIONSREQUEST._serialized_end=337
  _QUERYSESSIONSFORADDRESSREQUEST._serialized_start=340
  _QUERYSESSIONSFORADDRESSREQUEST._serialized_end=492
  _QUERYSESSIONREQUEST._serialized_start=494
  _QUERYSESSIONREQUEST._serialized_end=527
  _QUERYPARAMSREQUEST._serialized_start=529
  _QUERYPARAMSREQUEST._serialized_end=549
  _QUERYSESSIONSRESPONSE._serialized_start=552
  _QUERYSESSIONSRESPONSE._serialized_end=690
  _QUERYSESSIONSFORADDRESSRESPONSE._serialized_start=693
  _QUERYSESSIONSFORADDRESSRESPONSE._serialized_end=841
  _QUERYSESSIONRESPONSE._serialized_start=843
  _QUERYSESSIONRESPONSE._serialized_end=918
  _QUERYPARAMSRESPONSE._serialized_start=920
  _QUERYPARAMSRESPONSE._serialized_end=992
  _QUERYSERVICE._serialized_start=995
  _QUERYSERVICE._serialized_end=1600
# @@protoc_insertion_point(module_scope)
