# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sentinel/subscription/v1/events.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from sentinel.types.v1 import status_pb2 as sentinel_dot_types_dot_v1_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%sentinel/subscription/v1/events.proto\x12\x18sentinel.subscription.v1\x1a\x14gogoproto/gogo.proto\x1a\x1esentinel/types/v1/status.proto\"i\n\x0e\x45ventSubscribe\x12\x19\n\x02id\x18\x01 \x01(\x04\x42\r\xf2\xde\x1f\tyaml:\"id\"\x12\x1d\n\x04node\x18\x02 \x01(\tB\x0f\xf2\xde\x1f\x0byaml:\"node\"\x12\x1d\n\x04plan\x18\x03 \x01(\x04\x42\x0f\xf2\xde\x1f\x0byaml:\"plan\"\"i\n\x0e\x45ventSetStatus\x12\x19\n\x02id\x18\x01 \x01(\x04\x42\r\xf2\xde\x1f\tyaml:\"id\"\x12<\n\x06status\x18\x02 \x01(\x0e\x32\x19.sentinel.types.v1.StatusB\x11\xf2\xde\x1f\ryaml:\"status\"\"O\n\rEventAddQuota\x12\x19\n\x02id\x18\x01 \x01(\x04\x42\r\xf2\xde\x1f\tyaml:\"id\"\x12#\n\x07\x61\x64\x64ress\x18\x02 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:\"address\"\"R\n\x10\x45ventUpdateQuota\x12\x19\n\x02id\x18\x01 \x01(\x04\x42\r\xf2\xde\x1f\tyaml:\"id\"\x12#\n\x07\x61\x64\x64ress\x18\x02 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:\"address\"B?Z5github.com/sentinel-official/hub/x/subscription/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.subscription.v1.events_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z5github.com/sentinel-official/hub/x/subscription/types\250\342\036\000\310\341\036\000'
  _EVENTSUBSCRIBE.fields_by_name['id']._options = None
  _EVENTSUBSCRIBE.fields_by_name['id']._serialized_options = b'\362\336\037\tyaml:\"id\"'
  _EVENTSUBSCRIBE.fields_by_name['node']._options = None
  _EVENTSUBSCRIBE.fields_by_name['node']._serialized_options = b'\362\336\037\013yaml:\"node\"'
  _EVENTSUBSCRIBE.fields_by_name['plan']._options = None
  _EVENTSUBSCRIBE.fields_by_name['plan']._serialized_options = b'\362\336\037\013yaml:\"plan\"'
  _EVENTSETSTATUS.fields_by_name['id']._options = None
  _EVENTSETSTATUS.fields_by_name['id']._serialized_options = b'\362\336\037\tyaml:\"id\"'
  _EVENTSETSTATUS.fields_by_name['status']._options = None
  _EVENTSETSTATUS.fields_by_name['status']._serialized_options = b'\362\336\037\ryaml:\"status\"'
  _EVENTADDQUOTA.fields_by_name['id']._options = None
  _EVENTADDQUOTA.fields_by_name['id']._serialized_options = b'\362\336\037\tyaml:\"id\"'
  _EVENTADDQUOTA.fields_by_name['address']._options = None
  _EVENTADDQUOTA.fields_by_name['address']._serialized_options = b'\362\336\037\016yaml:\"address\"'
  _EVENTUPDATEQUOTA.fields_by_name['id']._options = None
  _EVENTUPDATEQUOTA.fields_by_name['id']._serialized_options = b'\362\336\037\tyaml:\"id\"'
  _EVENTUPDATEQUOTA.fields_by_name['address']._options = None
  _EVENTUPDATEQUOTA.fields_by_name['address']._serialized_options = b'\362\336\037\016yaml:\"address\"'
  _EVENTSUBSCRIBE._serialized_start=121
  _EVENTSUBSCRIBE._serialized_end=226
  _EVENTSETSTATUS._serialized_start=228
  _EVENTSETSTATUS._serialized_end=333
  _EVENTADDQUOTA._serialized_start=335
  _EVENTADDQUOTA._serialized_end=414
  _EVENTUPDATEQUOTA._serialized_start=416
  _EVENTUPDATEQUOTA._serialized_end=498
# @@protoc_insertion_point(module_scope)
