# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sentinel/subscription/v1/msg.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"sentinel/subscription/v1/msg.proto\x12\x18sentinel.subscription.v1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"k\n\x19MsgSubscribeToNodeRequest\x12\x0b\n\x03\x66rm\x18\x01 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\t\x12\x30\n\x07\x64\x65posit\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\"C\n\x19MsgSubscribeToPlanRequest\x12\x0b\n\x03\x66rm\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\x04\x12\r\n\x05\x64\x65nom\x18\x03 \x01(\t\"+\n\x10MsgCancelRequest\x12\x0b\n\x03\x66rm\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\x04\"}\n\x12MsgAddQuotaRequest\x12\x0b\n\x03\x66rm\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\x04\x12\x0f\n\x07\x61\x64\x64ress\x18\x03 \x01(\t\x12=\n\x05\x62ytes\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\"\x80\x01\n\x15MsgUpdateQuotaRequest\x12\x0b\n\x03\x66rm\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\x04\x12\x0f\n\x07\x61\x64\x64ress\x18\x03 \x01(\t\x12=\n\x05\x62ytes\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\"\x1c\n\x1aMsgSubscribeToNodeResponse\"\x1c\n\x1aMsgSubscribeToPlanResponse\"\x13\n\x11MsgCancelResponse\"\x15\n\x13MsgAddQuotaResponse\"\x18\n\x16MsgUpdateQuotaResponse2\xd5\x04\n\nMsgService\x12\x7f\n\x12MsgSubscribeToNode\x12\x33.sentinel.subscription.v1.MsgSubscribeToNodeRequest\x1a\x34.sentinel.subscription.v1.MsgSubscribeToNodeResponse\x12\x7f\n\x12MsgSubscribeToPlan\x12\x33.sentinel.subscription.v1.MsgSubscribeToPlanRequest\x1a\x34.sentinel.subscription.v1.MsgSubscribeToPlanResponse\x12\x64\n\tMsgCancel\x12*.sentinel.subscription.v1.MsgCancelRequest\x1a+.sentinel.subscription.v1.MsgCancelResponse\x12j\n\x0bMsgAddQuota\x12,.sentinel.subscription.v1.MsgAddQuotaRequest\x1a-.sentinel.subscription.v1.MsgAddQuotaResponse\x12s\n\x0eMsgUpdateQuota\x12/.sentinel.subscription.v1.MsgUpdateQuotaRequest\x1a\x30.sentinel.subscription.v1.MsgUpdateQuotaResponseB?Z5github.com/sentinel-official/hub/x/subscription/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.subscription.v1.msg_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z5github.com/sentinel-official/hub/x/subscription/types\250\342\036\000\310\341\036\000'
  _MSGSUBSCRIBETONODEREQUEST.fields_by_name['deposit']._options = None
  _MSGSUBSCRIBETONODEREQUEST.fields_by_name['deposit']._serialized_options = b'\310\336\037\000'
  _MSGADDQUOTAREQUEST.fields_by_name['bytes']._options = None
  _MSGADDQUOTAREQUEST.fields_by_name['bytes']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000'
  _MSGUPDATEQUOTAREQUEST.fields_by_name['bytes']._options = None
  _MSGUPDATEQUOTAREQUEST.fields_by_name['bytes']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000'
  _MSGSUBSCRIBETONODEREQUEST._serialized_start=118
  _MSGSUBSCRIBETONODEREQUEST._serialized_end=225
  _MSGSUBSCRIBETOPLANREQUEST._serialized_start=227
  _MSGSUBSCRIBETOPLANREQUEST._serialized_end=294
  _MSGCANCELREQUEST._serialized_start=296
  _MSGCANCELREQUEST._serialized_end=339
  _MSGADDQUOTAREQUEST._serialized_start=341
  _MSGADDQUOTAREQUEST._serialized_end=466
  _MSGUPDATEQUOTAREQUEST._serialized_start=469
  _MSGUPDATEQUOTAREQUEST._serialized_end=597
  _MSGSUBSCRIBETONODERESPONSE._serialized_start=599
  _MSGSUBSCRIBETONODERESPONSE._serialized_end=627
  _MSGSUBSCRIBETOPLANRESPONSE._serialized_start=629
  _MSGSUBSCRIBETOPLANRESPONSE._serialized_end=657
  _MSGCANCELRESPONSE._serialized_start=659
  _MSGCANCELRESPONSE._serialized_end=678
  _MSGADDQUOTARESPONSE._serialized_start=680
  _MSGADDQUOTARESPONSE._serialized_end=701
  _MSGUPDATEQUOTARESPONSE._serialized_start=703
  _MSGUPDATEQUOTARESPONSE._serialized_end=727
  _MSGSERVICE._serialized_start=730
  _MSGSERVICE._serialized_end=1327
# @@protoc_insertion_point(module_scope)
