# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sentinel/subscription/v1/genesis.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from sentinel.subscription.v1 import params_pb2 as sentinel_dot_subscription_dot_v1_dot_params__pb2
from sentinel.subscription.v1 import quota_pb2 as sentinel_dot_subscription_dot_v1_dot_quota__pb2
from sentinel.subscription.v1 import subscription_pb2 as sentinel_dot_subscription_dot_v1_dot_subscription__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&sentinel/subscription/v1/genesis.proto\x12\x18sentinel.subscription.v1\x1a\x14gogoproto/gogo.proto\x1a%sentinel/subscription/v1/params.proto\x1a$sentinel/subscription/v1/quota.proto\x1a+sentinel/subscription/v1/subscription.proto\"\x95\x01\n\x13GenesisSubscription\x12G\n\x0csubscription\x18\x01 \x01(\x0b\x32&.sentinel.subscription.v1.SubscriptionB\t\xea\xde\x1f\x01_\xc8\xde\x1f\x00\x12\x35\n\x06quotas\x18\x02 \x03(\x0b\x32\x1f.sentinel.subscription.v1.QuotaB\x04\xc8\xde\x1f\x00\"\xa1\x01\n\x0cGenesisState\x12Y\n\rsubscriptions\x18\x01 \x03(\x0b\x32-.sentinel.subscription.v1.GenesisSubscriptionB\x13\xea\xde\x1f\x0b_,omitempty\xc8\xde\x1f\x00\x12\x36\n\x06params\x18\x02 \x01(\x0b\x32 .sentinel.subscription.v1.ParamsB\x04\xc8\xde\x1f\x00\x42?Z5github.com/sentinel-official/hub/x/subscription/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.subscription.v1.genesis_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z5github.com/sentinel-official/hub/x/subscription/types\250\342\036\000\310\341\036\000'
  _GENESISSUBSCRIPTION.fields_by_name['subscription']._options = None
  _GENESISSUBSCRIPTION.fields_by_name['subscription']._serialized_options = b'\352\336\037\001_\310\336\037\000'
  _GENESISSUBSCRIPTION.fields_by_name['quotas']._options = None
  _GENESISSUBSCRIPTION.fields_by_name['quotas']._serialized_options = b'\310\336\037\000'
  _GENESISSTATE.fields_by_name['subscriptions']._options = None
  _GENESISSTATE.fields_by_name['subscriptions']._serialized_options = b'\352\336\037\013_,omitempty\310\336\037\000'
  _GENESISSTATE.fields_by_name['params']._options = None
  _GENESISSTATE.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _GENESISSUBSCRIPTION._serialized_start=213
  _GENESISSUBSCRIPTION._serialized_end=362
  _GENESISSTATE._serialized_start=365
  _GENESISSTATE._serialized_end=526
# @@protoc_insertion_point(module_scope)
