syntax = "proto3";

package ibc.lightclients.localhost.v1;

option go_package = "github.com/cosmos/ibc-go/v3/modules/light-clients/09-localhost/types";

import "gogoproto/gogo.proto";
import "ibc/core/client/v1/client.proto";

// ClientState defines a loopback (localhost) client. It requires (read-only)
// access to keys outside the client prefix.
message ClientState {
  option (gogoproto.goproto_getters) = false;
  // self chain ID
  string chain_id = 1 [(gogoproto.moretags) = "yaml:\"chain_id\""];
  // self latest block height
  ibc.core.client.v1.Height height = 2 [(gogoproto.nullable) = false];
}
