syntax = "proto3";
package sentinel.deposit.v1;

import "cosmos/base/v1beta1/coin.proto";
import "gogoproto/gogo.proto";

option go_package = "github.com/sentinel-official/hub/x/deposit/types";
option (gogoproto.equal_all)           = false;
option (gogoproto.goproto_getters_all) = false;

message EventAdd {
  string address = 1 [ (gogoproto.moretags) = "yaml:\"address\"" ];
  repeated cosmos.base.v1beta1.Coin coins = 2 [
    (gogoproto.nullable)     = false,
    (gogoproto.castrepeated) = "github.com/cosmos/cosmos-sdk/types.Coins",
    (gogoproto.moretags)     = "yaml:\"coins\""
  ];
}

message EventSubtract {
  string address = 1 [ (gogoproto.moretags) = "yaml:\"address\"" ];
  repeated cosmos.base.v1beta1.Coin coins = 2 [
    (gogoproto.nullable)     = false,
    (gogoproto.castrepeated) = "github.com/cosmos/cosmos-sdk/types.Coins",
    (gogoproto.moretags)     = "yaml:\"coins\""
  ];
}
