syntax = "proto3";
package interchain_security.ccv.v1;

// this line is used by starport scaffolding # proto/tx/import

option go_package = "github.com/cosmos/interchain-security/x/ccv/types";

// Msg defines the Msg service.
service Msg {
  // this line is used by starport scaffolding # proto/tx/rpc
}

// this line is used by starport scaffolding # proto/tx/message
