from google.protobuf import descriptor_pb2 as _descriptor_pb2
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

BENCHGEN_ALL_FIELD_NUMBER: _ClassVar[int]
BENCHGEN_FIELD_NUMBER: _ClassVar[int]
CASTKEY_FIELD_NUMBER: _ClassVar[int]
CASTREPEATED_FIELD_NUMBER: _ClassVar[int]
CASTTYPE_FIELD_NUMBER: _ClassVar[int]
CASTVALUE_FIELD_NUMBER: _ClassVar[int]
COMPARE_ALL_FIELD_NUMBER: _ClassVar[int]
COMPARE_FIELD_NUMBER: _ClassVar[int]
CUSTOMNAME_FIELD_NUMBER: _ClassVar[int]
CUSTOMTYPE_FIELD_NUMBER: _ClassVar[int]
DESCRIPTION_ALL_FIELD_NUMBER: _ClassVar[int]
DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
DESCRIPTOR: _descriptor.FileDescriptor
EMBED_FIELD_NUMBER: _ClassVar[int]
ENUMDECL_ALL_FIELD_NUMBER: _ClassVar[int]
ENUMDECL_FIELD_NUMBER: _ClassVar[int]
ENUMVALUE_CUSTOMNAME_FIELD_NUMBER: _ClassVar[int]
ENUM_CUSTOMNAME_FIELD_NUMBER: _ClassVar[int]
ENUM_STRINGER_ALL_FIELD_NUMBER: _ClassVar[int]
ENUM_STRINGER_FIELD_NUMBER: _ClassVar[int]
EQUAL_ALL_FIELD_NUMBER: _ClassVar[int]
EQUAL_FIELD_NUMBER: _ClassVar[int]
FACE_ALL_FIELD_NUMBER: _ClassVar[int]
FACE_FIELD_NUMBER: _ClassVar[int]
GOGOPROTO_IMPORT_FIELD_NUMBER: _ClassVar[int]
GOPROTO_ENUM_PREFIX_ALL_FIELD_NUMBER: _ClassVar[int]
GOPROTO_ENUM_PREFIX_FIELD_NUMBER: _ClassVar[int]
GOPROTO_ENUM_STRINGER_ALL_FIELD_NUMBER: _ClassVar[int]
GOPROTO_ENUM_STRINGER_FIELD_NUMBER: _ClassVar[int]
GOPROTO_EXTENSIONS_MAP_ALL_FIELD_NUMBER: _ClassVar[int]
GOPROTO_EXTENSIONS_MAP_FIELD_NUMBER: _ClassVar[int]
GOPROTO_GETTERS_ALL_FIELD_NUMBER: _ClassVar[int]
GOPROTO_GETTERS_FIELD_NUMBER: _ClassVar[int]
GOPROTO_REGISTRATION_FIELD_NUMBER: _ClassVar[int]
GOPROTO_SIZECACHE_ALL_FIELD_NUMBER: _ClassVar[int]
GOPROTO_SIZECACHE_FIELD_NUMBER: _ClassVar[int]
GOPROTO_STRINGER_ALL_FIELD_NUMBER: _ClassVar[int]
GOPROTO_STRINGER_FIELD_NUMBER: _ClassVar[int]
GOPROTO_UNKEYED_ALL_FIELD_NUMBER: _ClassVar[int]
GOPROTO_UNKEYED_FIELD_NUMBER: _ClassVar[int]
GOPROTO_UNRECOGNIZED_ALL_FIELD_NUMBER: _ClassVar[int]
GOPROTO_UNRECOGNIZED_FIELD_NUMBER: _ClassVar[int]
GOSTRING_ALL_FIELD_NUMBER: _ClassVar[int]
GOSTRING_FIELD_NUMBER: _ClassVar[int]
JSONTAG_FIELD_NUMBER: _ClassVar[int]
MARSHALER_ALL_FIELD_NUMBER: _ClassVar[int]
MARSHALER_FIELD_NUMBER: _ClassVar[int]
MESSAGENAME_ALL_FIELD_NUMBER: _ClassVar[int]
MESSAGENAME_FIELD_NUMBER: _ClassVar[int]
MORETAGS_FIELD_NUMBER: _ClassVar[int]
NULLABLE_FIELD_NUMBER: _ClassVar[int]
ONLYONE_ALL_FIELD_NUMBER: _ClassVar[int]
ONLYONE_FIELD_NUMBER: _ClassVar[int]
POPULATE_ALL_FIELD_NUMBER: _ClassVar[int]
POPULATE_FIELD_NUMBER: _ClassVar[int]
PROTOSIZER_ALL_FIELD_NUMBER: _ClassVar[int]
PROTOSIZER_FIELD_NUMBER: _ClassVar[int]
SIZER_ALL_FIELD_NUMBER: _ClassVar[int]
SIZER_FIELD_NUMBER: _ClassVar[int]
STABLE_MARSHALER_ALL_FIELD_NUMBER: _ClassVar[int]
STABLE_MARSHALER_FIELD_NUMBER: _ClassVar[int]
STDDURATION_FIELD_NUMBER: _ClassVar[int]
STDTIME_FIELD_NUMBER: _ClassVar[int]
STRINGER_ALL_FIELD_NUMBER: _ClassVar[int]
STRINGER_FIELD_NUMBER: _ClassVar[int]
TESTGEN_ALL_FIELD_NUMBER: _ClassVar[int]
TESTGEN_FIELD_NUMBER: _ClassVar[int]
TYPEDECL_ALL_FIELD_NUMBER: _ClassVar[int]
TYPEDECL_FIELD_NUMBER: _ClassVar[int]
UNMARSHALER_ALL_FIELD_NUMBER: _ClassVar[int]
UNMARSHALER_FIELD_NUMBER: _ClassVar[int]
UNSAFE_MARSHALER_ALL_FIELD_NUMBER: _ClassVar[int]
UNSAFE_MARSHALER_FIELD_NUMBER: _ClassVar[int]
UNSAFE_UNMARSHALER_ALL_FIELD_NUMBER: _ClassVar[int]
UNSAFE_UNMARSHALER_FIELD_NUMBER: _ClassVar[int]
VERBOSE_EQUAL_ALL_FIELD_NUMBER: _ClassVar[int]
VERBOSE_EQUAL_FIELD_NUMBER: _ClassVar[int]
WKTPOINTER_FIELD_NUMBER: _ClassVar[int]
benchgen: _descriptor.FieldDescriptor
benchgen_all: _descriptor.FieldDescriptor
castkey: _descriptor.FieldDescriptor
castrepeated: _descriptor.FieldDescriptor
casttype: _descriptor.FieldDescriptor
castvalue: _descriptor.FieldDescriptor
compare: _descriptor.FieldDescriptor
compare_all: _descriptor.FieldDescriptor
customname: _descriptor.FieldDescriptor
customtype: _descriptor.FieldDescriptor
description: _descriptor.FieldDescriptor
description_all: _descriptor.FieldDescriptor
embed: _descriptor.FieldDescriptor
enum_customname: _descriptor.FieldDescriptor
enum_stringer: _descriptor.FieldDescriptor
enum_stringer_all: _descriptor.FieldDescriptor
enumdecl: _descriptor.FieldDescriptor
enumdecl_all: _descriptor.FieldDescriptor
enumvalue_customname: _descriptor.FieldDescriptor
equal: _descriptor.FieldDescriptor
equal_all: _descriptor.FieldDescriptor
face: _descriptor.FieldDescriptor
face_all: _descriptor.FieldDescriptor
gogoproto_import: _descriptor.FieldDescriptor
goproto_enum_prefix: _descriptor.FieldDescriptor
goproto_enum_prefix_all: _descriptor.FieldDescriptor
goproto_enum_stringer: _descriptor.FieldDescriptor
goproto_enum_stringer_all: _descriptor.FieldDescriptor
goproto_extensions_map: _descriptor.FieldDescriptor
goproto_extensions_map_all: _descriptor.FieldDescriptor
goproto_getters: _descriptor.FieldDescriptor
goproto_getters_all: _descriptor.FieldDescriptor
goproto_registration: _descriptor.FieldDescriptor
goproto_sizecache: _descriptor.FieldDescriptor
goproto_sizecache_all: _descriptor.FieldDescriptor
goproto_stringer: _descriptor.FieldDescriptor
goproto_stringer_all: _descriptor.FieldDescriptor
goproto_unkeyed: _descriptor.FieldDescriptor
goproto_unkeyed_all: _descriptor.FieldDescriptor
goproto_unrecognized: _descriptor.FieldDescriptor
goproto_unrecognized_all: _descriptor.FieldDescriptor
gostring: _descriptor.FieldDescriptor
gostring_all: _descriptor.FieldDescriptor
jsontag: _descriptor.FieldDescriptor
marshaler: _descriptor.FieldDescriptor
marshaler_all: _descriptor.FieldDescriptor
messagename: _descriptor.FieldDescriptor
messagename_all: _descriptor.FieldDescriptor
moretags: _descriptor.FieldDescriptor
nullable: _descriptor.FieldDescriptor
onlyone: _descriptor.FieldDescriptor
onlyone_all: _descriptor.FieldDescriptor
populate: _descriptor.FieldDescriptor
populate_all: _descriptor.FieldDescriptor
protosizer: _descriptor.FieldDescriptor
protosizer_all: _descriptor.FieldDescriptor
sizer: _descriptor.FieldDescriptor
sizer_all: _descriptor.FieldDescriptor
stable_marshaler: _descriptor.FieldDescriptor
stable_marshaler_all: _descriptor.FieldDescriptor
stdduration: _descriptor.FieldDescriptor
stdtime: _descriptor.FieldDescriptor
stringer: _descriptor.FieldDescriptor
stringer_all: _descriptor.FieldDescriptor
testgen: _descriptor.FieldDescriptor
testgen_all: _descriptor.FieldDescriptor
typedecl: _descriptor.FieldDescriptor
typedecl_all: _descriptor.FieldDescriptor
unmarshaler: _descriptor.FieldDescriptor
unmarshaler_all: _descriptor.FieldDescriptor
unsafe_marshaler: _descriptor.FieldDescriptor
unsafe_marshaler_all: _descriptor.FieldDescriptor
unsafe_unmarshaler: _descriptor.FieldDescriptor
unsafe_unmarshaler_all: _descriptor.FieldDescriptor
verbose_equal: _descriptor.FieldDescriptor
verbose_equal_all: _descriptor.FieldDescriptor
wktpointer: _descriptor.FieldDescriptor
