# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sentinel/node/v1/msg.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from sentinel.types.v1 import status_pb2 as sentinel_dot_types_dot_v1_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1asentinel/node/v1/msg.proto\x12\x10sentinel.node.v1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x1esentinel/types/v1/status.proto\"\xb2\x01\n\x12MsgRegisterRequest\x12\x0b\n\x03\x66rm\x18\x01 \x01(\t\x12\x10\n\x08provider\x18\x02 \x01(\t\x12Z\n\x05price\x18\x03 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12!\n\nremote_url\x18\x04 \x01(\tB\r\xe2\xde\x1f\tRemoteURL\"\xb0\x01\n\x10MsgUpdateRequest\x12\x0b\n\x03\x66rm\x18\x01 \x01(\t\x12\x10\n\x08provider\x18\x02 \x01(\t\x12Z\n\x05price\x18\x03 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12!\n\nremote_url\x18\x04 \x01(\tB\r\xe2\xde\x1f\tRemoteURL\"M\n\x13MsgSetStatusRequest\x12\x0b\n\x03\x66rm\x18\x01 \x01(\t\x12)\n\x06status\x18\x02 \x01(\x0e\x32\x19.sentinel.types.v1.Status\"\x15\n\x13MsgRegisterResponse\"\x13\n\x11MsgUpdateResponse\"\x16\n\x14MsgSetStatusResponse2\x9d\x02\n\nMsgService\x12Z\n\x0bMsgRegister\x12$.sentinel.node.v1.MsgRegisterRequest\x1a%.sentinel.node.v1.MsgRegisterResponse\x12T\n\tMsgUpdate\x12\".sentinel.node.v1.MsgUpdateRequest\x1a#.sentinel.node.v1.MsgUpdateResponse\x12]\n\x0cMsgSetStatus\x12%.sentinel.node.v1.MsgSetStatusRequest\x1a&.sentinel.node.v1.MsgSetStatusResponseB7Z-github.com/sentinel-official/hub/x/node/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.node.v1.msg_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/sentinel-official/hub/x/node/types\250\342\036\000\310\341\036\000'
  _MSGREGISTERREQUEST.fields_by_name['price']._options = None
  _MSGREGISTERREQUEST.fields_by_name['price']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _MSGREGISTERREQUEST.fields_by_name['remote_url']._options = None
  _MSGREGISTERREQUEST.fields_by_name['remote_url']._serialized_options = b'\342\336\037\tRemoteURL'
  _MSGUPDATEREQUEST.fields_by_name['price']._options = None
  _MSGUPDATEREQUEST.fields_by_name['price']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _MSGUPDATEREQUEST.fields_by_name['remote_url']._options = None
  _MSGUPDATEREQUEST.fields_by_name['remote_url']._serialized_options = b'\342\336\037\tRemoteURL'
  _MSGREGISTERREQUEST._serialized_start=135
  _MSGREGISTERREQUEST._serialized_end=313
  _MSGUPDATEREQUEST._serialized_start=316
  _MSGUPDATEREQUEST._serialized_end=492
  _MSGSETSTATUSREQUEST._serialized_start=494
  _MSGSETSTATUSREQUEST._serialized_end=571
  _MSGREGISTERRESPONSE._serialized_start=573
  _MSGREGISTERRESPONSE._serialized_end=594
  _MSGUPDATERESPONSE._serialized_start=596
  _MSGUPDATERESPONSE._serialized_end=615
  _MSGSETSTATUSRESPONSE._serialized_start=617
  _MSGSETSTATUSRESPONSE._serialized_end=639
  _MSGSERVICE._serialized_start=642
  _MSGSERVICE._serialized_end=927
# @@protoc_insertion_point(module_scope)
