# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sentinel/types/v1/status.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1esentinel/types/v1/status.proto\x12\x11sentinel.types.v1\x1a\x14gogoproto/gogo.proto*\xa5\x01\n\x06Status\x12\'\n\x12STATUS_UNSPECIFIED\x10\x00\x1a\x0f\x8a\x9d \x0bUnspecified\x12\x1d\n\rSTATUS_ACTIVE\x10\x01\x1a\n\x8a\x9d \x06\x41\x63tive\x12\x30\n\x17STATUS_INACTIVE_PENDING\x10\x02\x1a\x13\x8a\x9d \x0fInactivePending\x12!\n\x0fSTATUS_INACTIVE\x10\x03\x1a\x0c\x8a\x9d \x08InactiveB0Z&github.com/sentinel-official/hub/types\xc8\xe1\x1e\x00\xd0\xe1\x1e\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.types.v1.status_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z&github.com/sentinel-official/hub/types\310\341\036\000\320\341\036\000'
  _STATUS.values_by_name["STATUS_UNSPECIFIED"]._options = None
  _STATUS.values_by_name["STATUS_UNSPECIFIED"]._serialized_options = b'\212\235 \013Unspecified'
  _STATUS.values_by_name["STATUS_ACTIVE"]._options = None
  _STATUS.values_by_name["STATUS_ACTIVE"]._serialized_options = b'\212\235 \006Active'
  _STATUS.values_by_name["STATUS_INACTIVE_PENDING"]._options = None
  _STATUS.values_by_name["STATUS_INACTIVE_PENDING"]._serialized_options = b'\212\235 \017InactivePending'
  _STATUS.values_by_name["STATUS_INACTIVE"]._options = None
  _STATUS.values_by_name["STATUS_INACTIVE"]._serialized_options = b'\212\235 \010Inactive'
  _STATUS._serialized_start=76
  _STATUS._serialized_end=241
# @@protoc_insertion_point(module_scope)
