syntax = "proto3";
package sentinel.session.v1;

option go_package = "github.com/sentinel-official/hub/x/session/types";

import "gogoproto/gogo.proto";
import "google/protobuf/duration.proto";
import "google/protobuf/timestamp.proto";
import "sentinel/types/v1/bandwidth.proto";
import "sentinel/types/v1/status.proto";

option (gogoproto.equal_all)           = false;
option (gogoproto.goproto_getters_all) = false;

message Session {
  uint64 id                         = 1;
  uint64 subscription               = 2;
  string node                       = 3;
  string address                    = 4;
  google.protobuf.Duration duration = 5
      [ (gogoproto.stdduration) = true, (gogoproto.nullable) = false ];
  sentinel.types.v1.Bandwidth bandwidth = 6 [ (gogoproto.nullable) = false ];
  sentinel.types.v1.Status status       = 7;
  google.protobuf.Timestamp status_at   = 8
      [ (gogoproto.nullable) = false, (gogoproto.stdtime) = true ];
}
