# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sentinel/node/v1/querier.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from sentinel.types.v1 import status_pb2 as sentinel_dot_types_dot_v1_dot_status__pb2
from sentinel.node.v1 import node_pb2 as sentinel_dot_node_dot_v1_dot_node__pb2
from sentinel.node.v1 import params_pb2 as sentinel_dot_node_dot_v1_dot_params__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1esentinel/node/v1/querier.proto\x12\x10sentinel.node.v1\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1esentinel/types/v1/status.proto\x1a\x1bsentinel/node/v1/node.proto\x1a\x1dsentinel/node/v1/params.proto\"z\n\x11QueryNodesRequest\x12)\n\x06status\x18\x01 \x01(\x0e\x32\x19.sentinel.types.v1.Status\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x96\x01\n\x1cQueryNodesForProviderRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12)\n\x06status\x18\x02 \x01(\x0e\x32\x19.sentinel.types.v1.Status\x12:\n\npagination\x18\x03 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"#\n\x10QueryNodeRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\"\x14\n\x12QueryParamsRequest\"~\n\x12QueryNodesResponse\x12+\n\x05nodes\x18\x01 \x03(\x0b\x32\x16.sentinel.node.v1.NodeB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"\x89\x01\n\x1dQueryNodesForProviderResponse\x12+\n\x05nodes\x18\x01 \x03(\x0b\x32\x16.sentinel.node.v1.NodeB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"?\n\x11QueryNodeResponse\x12*\n\x04node\x18\x01 \x01(\x0b\x32\x16.sentinel.node.v1.NodeB\x04\xc8\xde\x1f\x00\"E\n\x13QueryParamsResponse\x12.\n\x06params\x18\x01 \x01(\x0b\x32\x18.sentinel.node.v1.ParamsB\x04\xc8\xde\x1f\x00\x32\xa5\x04\n\x0cQueryService\x12p\n\nQueryNodes\x12#.sentinel.node.v1.QueryNodesRequest\x1a$.sentinel.node.v1.QueryNodesResponse\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/sentinel/nodes\x12\xa5\x01\n\x15QueryNodesForProvider\x12..sentinel.node.v1.QueryNodesForProviderRequest\x1a/.sentinel.node.v1.QueryNodesForProviderResponse\"+\x82\xd3\xe4\x93\x02%\x12#/sentinel/providers/{address}/nodes\x12w\n\tQueryNode\x12\".sentinel.node.v1.QueryNodeRequest\x1a#.sentinel.node.v1.QueryNodeResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/sentinel/nodes/{address}\x12\x81\x01\n\x0bQueryParams\x12$.sentinel.node.v1.QueryParamsRequest\x1a%.sentinel.node.v1.QueryParamsResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/sentinel/modules/node/paramsB7Z-github.com/sentinel-official/hub/x/node/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.node.v1.querier_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/sentinel-official/hub/x/node/types\250\342\036\000\310\341\036\000'
  _QUERYNODESRESPONSE.fields_by_name['nodes']._options = None
  _QUERYNODESRESPONSE.fields_by_name['nodes']._serialized_options = b'\310\336\037\000'
  _QUERYNODESFORPROVIDERRESPONSE.fields_by_name['nodes']._options = None
  _QUERYNODESFORPROVIDERRESPONSE.fields_by_name['nodes']._serialized_options = b'\310\336\037\000'
  _QUERYNODERESPONSE.fields_by_name['node']._options = None
  _QUERYNODERESPONSE.fields_by_name['node']._serialized_options = b'\310\336\037\000'
  _QUERYPARAMSRESPONSE.fields_by_name['params']._options = None
  _QUERYPARAMSRESPONSE.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _QUERYSERVICE.methods_by_name['QueryNodes']._options = None
  _QUERYSERVICE.methods_by_name['QueryNodes']._serialized_options = b'\202\323\344\223\002\021\022\017/sentinel/nodes'
  _QUERYSERVICE.methods_by_name['QueryNodesForProvider']._options = None
  _QUERYSERVICE.methods_by_name['QueryNodesForProvider']._serialized_options = b'\202\323\344\223\002%\022#/sentinel/providers/{address}/nodes'
  _QUERYSERVICE.methods_by_name['QueryNode']._options = None
  _QUERYSERVICE.methods_by_name['QueryNode']._serialized_options = b'\202\323\344\223\002\033\022\031/sentinel/nodes/{address}'
  _QUERYSERVICE.methods_by_name['QueryParams']._options = None
  _QUERYSERVICE.methods_by_name['QueryParams']._serialized_options = b'\202\323\344\223\002\037\022\035/sentinel/modules/node/params'
  _QUERYNODESREQUEST._serialized_start=240
  _QUERYNODESREQUEST._serialized_end=362
  _QUERYNODESFORPROVIDERREQUEST._serialized_start=365
  _QUERYNODESFORPROVIDERREQUEST._serialized_end=515
  _QUERYNODEREQUEST._serialized_start=517
  _QUERYNODEREQUEST._serialized_end=552
  _QUERYPARAMSREQUEST._serialized_start=554
  _QUERYPARAMSREQUEST._serialized_end=574
  _QUERYNODESRESPONSE._serialized_start=576
  _QUERYNODESRESPONSE._serialized_end=702
  _QUERYNODESFORPROVIDERRESPONSE._serialized_start=705
  _QUERYNODESFORPROVIDERRESPONSE._serialized_end=842
  _QUERYNODERESPONSE._serialized_start=844
  _QUERYNODERESPONSE._serialized_end=907
  _QUERYPARAMSRESPONSE._serialized_start=909
  _QUERYPARAMSRESPONSE._serialized_end=978
  _QUERYSERVICE._serialized_start=981
  _QUERYSERVICE._serialized_end=1530
# @@protoc_insertion_point(module_scope)
